@@ -16,7 +16,7 @@ use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION = version->new('0.0.9');
+our $VERSION = version->new('0.0.10');
 
 my $opt = Getopt::Alt->new(
     {
@@ -38,9 +38,9 @@ my $opt = Getopt::Alt->new(
 
 sub _num_sort {
     my $A = $a;
-    $A =~ s/(\d+)/sprintf "%013d", $1/egxms;
+    $A =~ s/((0+)\d+)/sprintf "%03d", $2 eq '00' ? $1 : $2 eq '0' ? $1 * 10 : $1 * 100/egxms;
     my $B = $b;
-    $B =~ s/(\d+)/sprintf "%013d", $1/egxms;
+    $B =~ s/((0+)\d+)/sprintf "%03d", $2 eq '00' ? $1 : $2 eq '0' ? $1 * 10 : $1 * 100/egxms;
     $A cmp $B;
 }
 
@@ -93,7 +93,7 @@ Group::Git::Cmd::SinceRelease - Gets the number of commits each repository is ah
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::SinceRelease version 0.0.9
+This documentation refers to Group::Git::Cmd::SinceRelease version 0.0.10
 
 =head1 SYNOPSIS
 
